@@ -1,47 +1,40 @@
 #!/usr/bin/env python
 
-import copy
-import numarray as NA
+import numpy as NP
 from tables import *
 import random
 
 # This class is accessible only for the examples
 class Small(IsDescription):
-    """ A record has several columns. They are represented here as
-    class attributes, whose names are the column names and their
-    values will become their types. The IsDescription class will take care
-    the user will not add any new variables and that its type is
-    correct."""
-
-    var1 = StringCol(length=4, dflt="",pos=2)
-    var2 = IntCol(0,pos=1)
-    var3 = FloatCol(0,pos=0)
+    var1 = StringCol(itemsize=4 ,pos=2)
+    var2 = Int32Col(pos=1)
+    var3 = Float64Col(pos=0)
 
 # Define a user record to characterize some kind of particles
 class Medium(IsDescription):
-    name        = StringCol(length=16, dflt="",pos=0)  # 16-character String
-    float1      = Col("Float64", 2, NA.arange(2),pos=1)
-    #float1      = Col("Float64", 1, 2.3)
-    #float2      = Col("Float64", 1, 2.3)
-    #zADCcount    = Col("Int16", 1, 0)    # signed short integer
-    ADCcount    = Col("Int32", 1, 0,pos=6)    # signed short integer
-    grid_i      = Col("Int32", 1, 0,pos=7)    # integer
-    grid_j      = Col("Int32", 1, 0,pos=8)    # integer
-    pressure    = Col("Float32", 1, 0,pos=9)    # float  (single-precision)
-    energy      = Col("Float64", 1, 0,pos=2)    # double (double-precision)
+    name        = StringCol(itemsize=16, pos=0)  # 16-character String
+    float1      = Float64Col(shape=2, dflt=NP.arange(2),pos=1)
+    #float1      = Float64Col(dflt=2.3)
+    #float2      = Float64Col(dflt=2.3)
+    #zADCcount    = Int16Col()    # signed short integer
+    ADCcount    = Int32Col(pos=6)    # signed short integer
+    grid_i      = Int32Col(pos=7)    # integer
+    grid_j      = Int32Col(pos=8)    # integer
+    pressure    = Float32Col(pos=9)    # float  (single-precision)
+    energy      = Float64Col(pos=2)    # double (double-precision)
 
 # Define a user record to characterize some kind of particles
 class Big(IsDescription):
-    name        = StringCol(length=16, dflt="")  # 16-character String
-    float1      = Col("Float64", 32, NA.arange(32))
-    float2      = Col("Float64", 32, 2.2)
-    TDCcount    = Col("Int8", 1, 0)    # signed short integer
-    #ADCcount    = Col("Int32", 1, 0)
-    #ADCcount    = Col("Int16", 1, 0)    # signed short integer
-    grid_i      = Col("Int32", 1, 0)    # integer
-    grid_j      = Col("Int32", 1, 0)    # integer
-    pressure    = Col("Float32", 1, 0)    # float  (single-precision)
-    energy      = Col("Float64", 1, 0)    # double (double-precision)
+    name        = StringCol(itemsize=16)  # 16-character String
+    float1      = Float64Col(shape=32, dflt=NP.arange(32))
+    float2      = Float64Col(shape=32, dflt=2.2)
+    TDCcount    = Int8Col()    # signed short integer
+    #ADCcount    = Int32Col()
+    #ADCcount    = Int16Col()    # signed short integer
+    grid_i      = Int32Col()    # integer
+    grid_j      = Int32Col()    # integer
+    pressure    = Float32Col()    # float  (single-precision)
+    energy      = Float64Col()    # double (double-precision)
 
 def createFile(filename, totalrows, filters, recsize):
 
@@ -61,13 +54,13 @@ def createFile(filename, totalrows, filters, recsize):
             table = fileh.createTable(group, 'tuple'+str(j), Big, title,
                                       None,
                                       totalrows)
-            arr = NA.array(NA.arange(32), type=NA.Float64)
-            arr2 = NA.array(NA.arange(32), type=NA.Float64)
+            arr = NP.array(NP.arange(32), dtype=NP.float64)
+            arr2 = NP.array(NP.arange(32), dtype=NP.float64)
         elif recsize == "medium":
             table = fileh.createTable(group, 'tuple'+str(j), Medium, title,
                                       None,
                                       totalrows)
-            arr = NA.array(NA.arange(2), type=NA.Float64)
+            arr = NP.array(NP.arange(2), dtype=NP.float64)
         elif recsize == "small":
             table = fileh.createTable(group, 'tuple'+str(j), Small, title,
                                       None,
@@ -84,8 +77,8 @@ def createFile(filename, totalrows, filters, recsize):
             for i in xrange(totalrows):
                 # d['name']  = 'Part: %6d' % (i)
                 d['TDCcount'] = i % 256
-                #d['float1'] = NA.array([i]*32, NA.Float64)
-                #d['float2'] = NA.array([i**2]*32, NA.Float64)
+                #d['float1'] = NP.array([i]*32, NP.float64)
+                #d['float2'] = NP.array([i**2]*32, NP.float64)
                 #d['float1'][0] = float(i)
                 #d['float2'][0] = float(i*2)
                 # Common part with medium
@@ -99,7 +92,7 @@ def createFile(filename, totalrows, filters, recsize):
         elif recsize == "medium":
             for i in xrange(totalrows):
                 #d['name']  = 'Part: %6d' % (i)
-                #d['float1'] = NA.array([i]*2, NA.Float64)
+                #d['float1'] = NP.array([i]*2, NP.float64)
                 #d['float1'] = arr
                 #d['float1'] = i
                 #d['float2'] = float(i)
@@ -114,7 +107,7 @@ def createFile(filename, totalrows, filters, recsize):
             for i in xrange(totalrows):
                 #d['var1'] = str(random.randrange(1000000))
                 #d['var3'] = random.randrange(10000000)
-                #d['var1'] = str(i)
+                d['var1'] = str(i)
                 #d['var2'] = random.randrange(totalrows)
                 d['var2'] = i
                 #d['var3'] = 12.1e10
@@ -133,6 +126,7 @@ def createFile(filename, totalrows, filters, recsize):
         group2 = fileh.createGroup(group, 'group'+str(j))
         # Iterate over this new group (group2)
         group = group2
+        table.flush()
 
     # Close the file (eventually destroy the extended type)
     fileh.close()
@@ -150,10 +144,10 @@ def readFile(filename, recsize, verbose):
             rowsize = table.rowsize
             print "reading", table
             if verbose:
-                print "Max rows in buf:", table._v_maxTuples
+                print "Max rows in buf:", table.nrowsinbuf
                 print "Rows in", table._v_pathname, ":", table.nrows
-                print "Buffersize:", table.rowsize * table._v_maxTuples
-                print "MaxTuples:", table._v_maxTuples
+                print "Buffersize:", table.rowsize * table.nrowsinbuf
+                print "MaxTuples:", table.nrowsinbuf
 
             if recsize == "big" or recsize == "medium":
                 #e = [ p.float1 for p in table.iterrows()
@@ -166,7 +160,7 @@ def readFile(filename, recsize, verbose):
 #                       if p['grid_i'] <= 2 ]
 #                e = [ p['grid_i'] for p in table.where("grid_i<=20")]
                 e = [ p['grid_i'] for p in
-                      table.where(table.cols.grid_i<20)]
+                      table.where('grid_i <= 20')]
 #                 e = [ p['grid_i'] for p in table.iterrows()
 #                       if p.nrow() == 20 ]
 #                 e = [ table.delrow(p.nrow()) for p in table.iterrows()
@@ -203,9 +197,10 @@ def readFile(filename, recsize, verbose):
                      # than ten times faster than the next one
 #                e = [ p['var3'] for p in table
 #                      if p['var1'] == "10"]
-#                 e = [ p['var3'] for p in table.where(table.cols.var2 <=20)
-                e = [ p['var3'] for p in table
-                       if p['var2'] <= 10 ]
+                # e = [ p['var3'] for p in table.where('var2 <= 20')]
+                # e = [ p[0] for p in table.where('var2 <= 20')]
+                e = [ p['var3'] for p in table if p['var2'] <= 20 ]
+                # e = [ p[:] for p in table if p[1] <= 20 ]
 #                  e = [ p['var3'] for p in table._whereInRange(table.cols.var2 <=20)]
                 #e = [ p['var3'] for p in table.iterrows(0,21) ]
 #                  e = [ p['var3'] for p in table.iterrows()
@@ -243,12 +238,12 @@ def readField(filename, field, rng, verbose):
         row = 0
         for table in fileh.listNodes(groupobj, 'Table'):
             rowsize = table.rowsize
-            #table._v_maxTuples = 3 # For testing purposes
+            #table.nrowsinbuf = 3 # For testing purposes
             if verbose:
-                print "Max rows in buf:", table._v_maxTuples
+                print "Max rows in buf:", table.nrowsinbuf
                 print "Rows in", table._v_pathname, ":", table.nrows
-                print "Buffersize:", table.rowsize * table._v_maxTuples
-                print "MaxTuples:", table._v_maxTuples
+                print "Buffersize:", table.rowsize * table.nrowsinbuf
+                print "MaxTuples:", table.nrowsinbuf
                 print "(field, start, stop, step) ==>", (field, rng[0], rng[1], rng[2])
 
             e = table.read(rng[0], rng[1], rng[2], field)
@@ -357,7 +352,9 @@ if __name__=="__main__":
     file = pargs[0]
 
     if verbose:
-        print "numarray version:", NA.__version__
+        print "numpy version:", NP.__version__
+        if psyco_imported and usepsyco:
+            print "Using psyco version:", psyco.version_info
 
     if testwrite:
         print "Compression level:", complevel
