@@ -3,6 +3,8 @@
 
 #include <hdf5.h>
 
+#include "utils.h"
+
 #define TESTING(WHAT)	{printf("%-70s", "Testing " WHAT); fflush(stdout);}
 #define PASSED()	{puts(" PASSED");fflush(stdout);}
 #define H5_FAILED()	{puts("*FAILED*");fflush(stdout);}
@@ -17,7 +19,6 @@ herr_t H5ARRAYmake( hid_t loc_id,
 		    const char *dset_name,
 		    const char *class_,
 		    const char *title,
-		    const char *flavor,
 		    const char *obversion,
 		    const int rank,
 		    const hsize_t *dims,
@@ -82,13 +83,12 @@ herr_t H5ARRAYget_info( hid_t dataset_id,
 			hid_t type_id,
 			hsize_t *dims,
 			hsize_t *maxdims,
-			hid_t *super_type_id,
-			H5T_class_t *super_class_id,
+			H5T_class_t *class_id,
 			char *byteorder);
 
-herr_t H5ARRAYget_chunksize( hid_t dataset_id,
-			     int rank,
-			     hsize_t *dims_chunk);
+herr_t H5ARRAYget_chunkshape( hid_t dataset_id,
+			      int rank,
+			      hsize_t *dims_chunk);
 
 #ifdef __cplusplus
 }
