@@ -4,7 +4,7 @@
 #       Created: October 1, 2002
 #       Author:  Francesc Altet - faltet@carabos.com
 #
-#       $Id: __init__.py 1262 2005-09-30 14:56:04Z ivilata $
+#       $Id: __init__.py 2912 2007-05-22 15:31:47Z ivilata $
 #
 ########################################################################
 
@@ -24,6 +24,7 @@ Misc variables:
 
     __version__
     hdf5Version
+    is_pro
 
 """
 
@@ -31,31 +32,33 @@ Misc variables:
 from tables.utilsExtension import getPyTablesVersion, getHDF5Version
 
 __version__ = getPyTablesVersion()
+"""The PyTables version number."""
 hdf5Version = getHDF5Version()
+"""The underlying HDF5 library version number."""
+is_pro = __version__.endswith('pro')
+"""True for PyTables Professional edition, false otherwise."""
 
-from tables.utilsExtension import isHDF5  # deprecated
 from tables.utilsExtension import isHDF5File, isPyTablesFile, whichLibVersion
 
-from tables.enum import *
-from tables.Atom import *
-from tables.IsDescription import *
+from tables.misc.enum import Enum
+from tables.atom import *
+from tables.flavor import restrict_flavors
+from tables.description import *
+from tables.filters import Filters
 
 # Import the user classes from the proper modules
 from tables.exceptions import *
-from tables.File import File, openFile, copyFile
-from tables.Node import Node
-from tables.Group import Group
-from tables.Leaf import Leaf, Filters
-from tables.Index import IndexProps
-from tables.Table import Table, Cols, Column
-from tables.Array import Array
-from tables.CArray import CArray
-from tables.EArray import EArray
-from tables.VLArray import VLArray
-from tables.UnImplemented import UnImplemented
-
-# Import sub-packages
-##import nodes
+from tables.file import File, openFile, copyFile
+from tables.node import Node
+from tables.group import Group
+from tables.leaf import Leaf
+from tables.table import Table, Cols, Column
+from tables.array import Array
+from tables.carray import CArray
+from tables.earray import EArray
+from tables.vlarray import VLArray
+from tables.unimplemented import UnImplemented
+from tables.tests import print_versions, test
 
 
 # List here only the objects we want to be publicly available
@@ -66,27 +69,31 @@ __all__ = [
     'NaturalNameWarning', 'NodeError', 'NoSuchNodeError',
     'UndoRedoError', 'UndoRedoWarning',
     'PerformanceWarning',
+    'FlavorError', 'FlavorWarning',
+    'FiltersWarning',
     # Functions:
-    'isHDF5',  # deprecated
-    'isHDF5File', 'isPyTablesFile', 'whichLibVersion', 'copyFile', 'openFile',
+    'isHDF5File', 'isPyTablesFile', 'whichLibVersion',
+    'copyFile', 'openFile', 'print_versions', 'test',
+    'split_type', 'restrict_flavors',
     # Helper classes:
-    'IsDescription', 'Description', 'Filters', 'IndexProps', 'Cols', 'Column',
+    'IsDescription', 'Description', 'Filters', 'Cols', 'Column',
     # Types:
     'Enum',
     # Atom types:
-    'Atom', 'ObjectAtom', 'VLStringAtom', 'StringAtom', 'BoolAtom',
-    'IntAtom', 'Int8Atom', 'UInt8Atom', 'Int16Atom', 'UInt16Atom',
+    'Atom', 'StringAtom', 'BoolAtom',
+    'IntAtom', 'UIntAtom', 'Int8Atom', 'UInt8Atom', 'Int16Atom', 'UInt16Atom',
     'Int32Atom', 'UInt32Atom', 'Int64Atom', 'UInt64Atom',
     'FloatAtom', 'Float32Atom', 'Float64Atom',
-    'ComplexAtom', 'Complex32Atom', 'Complex64Atom',
+    'ComplexAtom', 'Complex32Atom', 'Complex64Atom', 'Complex128Atom',
     'TimeAtom', 'Time32Atom', 'Time64Atom',
     'EnumAtom',
+    'PseudoAtom', 'ObjectAtom', 'VLStringAtom', 'VLUnicodeAtom',
     # Column types:
-    'Col', 'BoolCol', 'StringCol',
-    'IntCol', 'Int8Col', 'UInt8Col', 'Int16Col', 'UInt16Col',
+    'Col', 'StringCol', 'BoolCol',
+    'IntCol', 'UIntCol', 'Int8Col', 'UInt8Col', 'Int16Col', 'UInt16Col',
     'Int32Col', 'UInt32Col', 'Int64Col', 'UInt64Col',
     'FloatCol', 'Float32Col', 'Float64Col',
-    'ComplexCol', 'Complex32Col', 'Complex64Col',
+    'ComplexCol', 'Complex32Col', 'Complex64Col', 'Complex128Col',
     'TimeCol', 'Time32Col', 'Time64Col',
     'EnumCol',
     # Node classes:
