@@ -4,7 +4,7 @@
 #       Created: December 17, 2004
 #       Author:  Francesc Altet - faltet@carabos.com
 #
-#       $Id: exceptions.py 1136 2005-07-29 12:17:24Z ivilata $
+#       $Id: exceptions.py 2522 2007-03-11 13:40:01Z ivilata $
 #
 ########################################################################
 
@@ -35,12 +35,24 @@ Classes:
     Issued when a non-pythonic name is given for a node.
 `PerformanceWarning`
     Warning for operations which may cause a performance drop.
+`FlavorError`
+    Unsupported or unavailable flavor or flavor conversion.
+`FlavorWarning`
+    Unsupported or unavailable flavor conversion.
+`FiltersWarning`
+    Unavailable filters.
+`NoIndexingError`
+    Indexing is not supported.
+`NoIndexingWarning`
+    Indexing is not supported.
+`OldIndexWarning`
+    Unsupported index format.
 """
 
 __docformat__ = 'reStructuredText'
 """The format of documentation strings in this module."""
 
-__version__ = '$Revision: 1136 $'
+__version__ = '$Revision: 2522 $'
 """Repository version of this file."""
 
 
@@ -169,6 +181,89 @@ class PerformanceWarning(Warning):
 
 
 
+class FlavorError(ValueError):
+    """
+    Unsupported or unavailable flavor or flavor conversion.
+
+    This exception is raised when an unsupported or unavailable flavor
+    is given to a dataset, or when a conversion of data between two
+    given flavors is not supported nor available.
+
+    A supported flavor may be unavailable if the package which
+    implements it is not installed locally, e.g. you may specify the
+    ``numeric`` flavor, which is supported by PyTables, but if Numeric
+    is not installed on your machine, you will get this error.
+    """
+    pass
+
+
+class FlavorWarning(Warning):
+    """
+    Unsupported or unavailable flavor conversion.
+
+    This warning is issued when a conversion of data between two given
+    flavors is not supported nor available, and raising an error would
+    render the data inaccessible (e.g. on a dataset of an unavailable
+    flavor in a read-only file).
+
+    See the `FlavorError` class for more information.
+    """
+    pass
+
+
+class FiltersWarning(Warning):
+    """
+    Unavailable filters.
+
+    This warning is issued when a valid filter is specified but it is
+    not available in the system.  It may mean that an available default
+    filter is to be used instead.
+    """
+    pass
+
+
+_no_indexing_message = (
+    "This version of PyTables does not support indexing. "
+    "Please consider using the PyTables Pro edition "
+    "(http://www.carabos.com/products/pytables-pro)." )
+
+class NoIndexingError(NotImplementedError):
+    """
+    Indexing is not supported.
+
+    This exception is raised when an indexing-related operation is
+    requested under a version of PyTables which does not support
+    indexing.  Please consider using the PyTables Pro edition
+    (http://www.carabos.com/products/pytables-pro).
+    """
+    def __init__(self):
+        NotImplementedError.__init__(self, _no_indexing_message)
+
+class NoIndexingWarning(Warning):
+    """
+    Indexing is not supported.
+
+    This warning is issued when opening an indexed table under a version
+    of PyTables which does not support indexing.  Please consider using
+    the PyTables Pro edition
+    (http://www.carabos.com/products/pytables-pro).
+    """
+    def __init__(self, message):
+        message = '%s. %s' % (message, _no_indexing_message)
+        Warning.__init__(self, message)
+
+class OldIndexWarning(Warning):
+    """
+    Unsupported index format.
+
+    This warning is issued when an index in an unsupported format is
+    found.  The index will be marked as invalid and will behave as if
+    doesn't exist.
+    """
+    pass
+
+
+
 ## Local Variables:
 ## mode: python
 ## py-indent-offset: 4
