@@ -6,139 +6,110 @@ Test module for enumerated types under PyTables
 :Contact:  ivilata@carabos.com
 :Created:  2005-05-09
 :License:  BSD
-:Revision: $Id: test_enum.py 1424 2006-02-02 12:09:30Z faltet $
+:Revision: $Id: test_enum.py 2381 2007-02-16 18:06:40Z ivilata $
 """
 
 import unittest
 import operator
 
+import numpy
+
 import tables
-import common
-from common import verbose
+from tables.tests import common
 
 
 class CreateColTestCase(common.PyTablesTestCase):
 
     """Test creating enumerated column descriptions."""
 
-    def _createCol(self, enum, dflt, dtype='UInt32', shape=1):
+    def _createCol(self, enum, dflt, base='uint32', shape=()):
         """Create and check an enumerated column description."""
 
-        enumcol = tables.EnumCol(enum, dflt, dtype=dtype, shape=shape)
+        enumcol = tables.EnumCol(enum, dflt, base=base, shape=shape)
         sameEnum = tables.Enum(enum)
-        self.assertEqual(enumcol.stype, 'Enum')
-        self.assertEqual(enumcol.type, dtype)
+        self.assertEqual(enumcol.type, 'enum')
+        self.assertEqual(enumcol.dtype.base.name, enumcol.base.type)
         # To avoid 'LongInt' vs 'Int' issues
         #self.assertEqual(enumcol.dflt, sameEnum[dflt])
         self.assertEqual(int(enumcol.dflt), int(sameEnum[dflt]))
-        self.assertEqual(enumcol.shape, shape)
+        self.assertEqual(enumcol.dtype.shape, shape)
         self.assertEqual(enumcol.enum, sameEnum)
 
 
     def test00a_validFromEnum(self):
         """Describing an enumerated column from an enumeration."""
-
-        self._verboseHeader()
         colors = tables.Enum(['red', 'green', 'blue'])
         self._createCol(colors, 'red')
 
     def test00b_validFromDict(self):
         """Describing an enumerated column from a dictionary."""
-
-        self._verboseHeader()
         colors = {'red': 4, 'green': 2, 'blue': 1}
         self._createCol(colors, 'red')
 
 
     def test00c_validFromList(self):
         """Describing an enumerated column from a list."""
-
-        self._verboseHeader()
         colors = ['red', 'green', 'blue']
         self._createCol(colors, 'red')
 
 
     def test00d_invalidFromType(self):
         """Describing an enumerated column from an invalid object."""
-
-        self._verboseHeader()
         colors = 123
         self.assertRaises(TypeError, self._createCol, colors, 'red')
 
 
-    def test01a_invalidDfltType(self):
+    def test01_invalidDflt(self):
         """Describing an enumerated column with an invalid default object."""
-
-        self._verboseHeader()
-        colors = tables.Enum({'red': 4, 'green': 2, 'blue': 1})
-        self.assertRaises(TypeError, self._createCol, colors, colors.red)
-
-
-    def test01b_invalidDfltName(self):
-        """Describing an enumerated column with an invalid default name."""
-
-        self._verboseHeader()
         colors = {'red': 4, 'green': 2, 'blue': 1}
         self.assertRaises(KeyError, self._createCol, colors, 'black')
 
 
     def test02a_validDtypeBroader(self):
         """Describing an enumerated column with a broader type."""
-
-        self._verboseHeader()
         colors = {'red': 4, 'green': 2, 'blue': 1}
-        self._createCol(colors, 'red', dtype='Int64')
+        self._createCol(colors, 'red', 'int64')
 
 
     def test02b_invalidDtypeTooNarrow(self):
         """Describing an enumerated column with a too narrow type."""
-
-        self._verboseHeader()
         colors = ['e%d' % i for i in range(300)]
-        self.assertRaises(TypeError, self._createCol, colors, 'e0', 'UInt8')
+        self.assertRaises(TypeError, self._createCol, colors, 'e0', 'uint8')
 
 
     def test03a_validShapeMD(self):
         """Describing an enumerated column with multidimensional shape."""
-
-        self._verboseHeader()
         colors = ['red', 'green', 'blue']
         self._createCol(colors, 'red', shape=(2,))
 
 
     def test04a_validReprEnum(self):
         """Checking the string representation of an enumeration."""
-
-        self._verboseHeader()
         colors = tables.Enum(['red', 'green', 'blue'])
-        enumcol = tables.EnumCol(colors, 'red', dtype='UInt32', shape=1)
+        enumcol = tables.EnumCol(colors, 'red', base='uint32', shape=())
         assert repr(enumcol) == \
-"""EnumCol(Enum({'blue': 2, 'green': 1, 'red': 0}), 'red', dtype='UInt32', shape=1, pos=None, indexed=False)"""
+"""EnumCol(enum=Enum({'blue': 2, 'green': 1, 'red': 0}), dflt='red', base=UInt32Atom(shape=(), dflt=0), shape=(), pos=None)"""
 
 
     def test99a_nonIntEnum(self):
         """Describing an enumerated column of floats (not implemented)."""
-
-        self._verboseHeader()
         colors = {'red': 1.0}
-        self.assertRaises(NotImplementedError, self._createCol, colors, 'red')
+        self.assertRaises(NotImplementedError, self._createCol, colors, 'red',
+                          base=tables.FloatAtom())
 
 
     def test99b_nonIntDtype(self):
         """Describing an enumerated column encoded as floats (not implemented)."""
-
-        self._verboseHeader()
         colors = ['red', 'green', 'blue']
         self.assertRaises(
-            NotImplementedError, self._createCol, colors, 'red', 'Float64')
+            NotImplementedError, self._createCol, colors, 'red', 'float64')
 
 
     def test99b_nonScalarEnum(self):
         """Describing an enumerated column of non-scalars (not implemented)."""
-
-        self._verboseHeader()
         colors = {'red': (1, 2, 3)}
-        self.assertRaises(NotImplementedError, self._createCol, colors, 'red')
+        self.assertRaises(NotImplementedError, self._createCol, colors, 'red',
+                          base=tables.IntAtom(shape=3))
 
 
 
@@ -146,96 +117,78 @@ class CreateAtomTestCase(common.PyTablesTestCase):
 
     """Test creating enumerated atoms."""
 
-    def _createAtom(self, enum, dtype='UInt32', shape=1):
+    def _createAtom(self, enum, dflt, base='uint32', shape=()):
         """Create and check an enumerated atom."""
 
-        enumatom = tables.EnumAtom(enum, dtype=dtype, shape=shape)
+        enumatom = tables.EnumAtom(enum, dflt, base=base, shape=shape)
         sameEnum = tables.Enum(enum)
-        self.assertEqual(enumatom.stype, 'Enum')
-        self.assertEqual(enumatom.type, dtype)
+        self.assertEqual(enumatom.type, 'enum')
+        self.assertEqual(enumatom.dtype.base.name, enumatom.base.type)
         self.assertEqual(enumatom.shape, shape)
         self.assertEqual(enumatom.enum, sameEnum)
 
 
     def test00a_validFromEnum(self):
         """Describing an enumerated atom from an enumeration."""
-
-        self._verboseHeader()
         colors = tables.Enum(['red', 'green', 'blue'])
-        self._createAtom(colors)
+        self._createAtom(colors, 'red')
 
 
     def test00b_validFromDict(self):
         """Describing an enumerated atom from a dictionary."""
-
-        self._verboseHeader()
         colors = {'red': 4, 'green': 2, 'blue': 1}
-        self._createAtom(colors)
+        self._createAtom(colors, 'red')
 
 
     def test00c_validFromList(self):
         """Describing an enumerated atom from a list."""
-
-        self._verboseHeader()
         colors = ['red', 'green', 'blue']
-        self._createAtom(colors)
+        self._createAtom(colors, 'red')
 
 
     def test00d_invalidFromType(self):
         """Describing an enumerated atom from an invalid object."""
-
-        self._verboseHeader()
         colors = 123
-        self.assertRaises(TypeError, self._createAtom, colors)
+        self.assertRaises(TypeError, self._createAtom, colors, 'red')
 
 
     def test02a_validDtypeBroader(self):
         """Describing an enumerated atom with a broader type."""
-
-        self._verboseHeader()
         colors = {'red': 4, 'green': 2, 'blue': 1}
-        self._createAtom(colors, dtype='Int64')
+        self._createAtom(colors, 'red', base='int64')
 
 
     def test02b_invalidDtypeTooNarrow(self):
         """Describing an enumerated atom with a too narrow type."""
-
-        self._verboseHeader()
         colors = ['e%d' % i for i in range(300)]
-        self.assertRaises(TypeError, self._createAtom, colors, 'UInt8')
+        self.assertRaises(TypeError, self._createAtom, colors, 'red', 'uint8')
 
 
     def test03a_validShapeMD(self):
         """Describing an enumerated atom with multidimensional shape."""
-
-        self._verboseHeader()
         colors = ['red', 'green', 'blue']
-        self._createAtom(colors, shape=(2,))
+        self._createAtom(colors, 'red', shape=(2,))
 
 
     def test99a_nonIntEnum(self):
         """Describing an enumerated atom of floats (not implemented)."""
-
-        self._verboseHeader()
         colors = {'red': 1.0}
-        self.assertRaises(NotImplementedError, self._createAtom, colors)
+        self.assertRaises(NotImplementedError, self._createAtom, colors, 'red',
+                          base=tables.FloatAtom())
 
 
     def test99b_nonIntDtype(self):
         """Describing an enumerated atom encoded as a float (not implemented)."""
-
-        self._verboseHeader()
         colors = ['red', 'green', 'blue']
         self.assertRaises(
-            NotImplementedError, self._createAtom, colors, 'Float64')
+            NotImplementedError, self._createAtom, colors, 'red', 'float64')
 
 
     def test99b_nonScalarEnum(self):
         """Describing an enumerated atom of non-scalars (not implemented)."""
-
-        self._verboseHeader()
         colors = {'red': (1, 2, 3)}
-        self.assertRaises(NotImplementedError, self._createAtom, colors)
+        self.assertRaises(NotImplementedError, self._createAtom, colors, 'red',
+                          base=tables.IntAtom(shape=3))
 
 
 
@@ -247,7 +200,7 @@ class EnumTableTestCase(common.TempFileMixin, common.PyTablesTestCase):
     defaultName = 'black'
     valueInEnum = enum.red
     valueOutOfEnum = 1234
-    enumType = 'UInt16'
+    enumType = 'uint16'
 
 
     def _description(self, shape=1):
@@ -255,7 +208,7 @@ class EnumTableTestCase(common.TempFileMixin, common.PyTablesTestCase):
             rid = tables.IntCol(pos=0)
             rcolor = tables.EnumCol(
                 self.enum, self.defaultName,
-                dtype=self.enumType, shape=shape, pos=1)
+                base=self.enumType, shape=shape, pos=1)
 
         return TestDescription
 
@@ -263,7 +216,6 @@ class EnumTableTestCase(common.TempFileMixin, common.PyTablesTestCase):
     def test00a_reopen(self):
         """Reopening a file with tables using enumerated data."""
 
-        self._verboseHeader()
         self.h5file.createTable(
             '/', 'test', self._description(), title=self._getMethodName())
 
@@ -280,7 +232,6 @@ class EnumTableTestCase(common.TempFileMixin, common.PyTablesTestCase):
         data.
         """
 
-        self._verboseHeader()
         self.h5file.createTable(
             '/', 'test', self._description((2,)), title=self._getMethodName())
 
@@ -294,7 +245,6 @@ class EnumTableTestCase(common.TempFileMixin, common.PyTablesTestCase):
     def test01_rowAppend(self):
         """Appending enumerated values using ``row.append()``."""
 
-        self._verboseHeader()
         tbl = self.h5file.createTable(
             '/', 'test', self._description(), title=self._getMethodName())
 
@@ -313,10 +263,12 @@ class EnumTableTestCase(common.TempFileMixin, common.PyTablesTestCase):
             ValueError, operator.setitem, row, 'rcolor', appended[1][1])
 
         tbl.flush()
-        read = tbl.read(flavor='python')
-        if verbose:
-            print "appended value:", appended[:-1]
-            print "read value:", read
+        tbl.flavor = 'python'
+        read = tbl.read()
+        common.verbosePrint(
+            "* appended value: %s\n"
+            "* read value: %s\n"
+            % (appended[:-1], read) )
         self.assertEqual(
             appended[:-1], read, "Written and read values differ.")
 
@@ -324,7 +276,6 @@ class EnumTableTestCase(common.TempFileMixin, common.PyTablesTestCase):
     def test02_append(self):
         """Appending enumerated values using ``table.append()``."""
 
-        self._verboseHeader()
         tbl = self.h5file.createTable(
             '/', 'test', self._description(), title=self._getMethodName())
 
@@ -334,17 +285,18 @@ class EnumTableTestCase(common.TempFileMixin, common.PyTablesTestCase):
 
         tbl.append(appended)
         tbl.flush()
-        read = tbl.read(flavor='python')
-        if verbose:
-            print "appended value:", appended
-            print "read value:", read
+        tbl.flavor = 'python'
+        read = tbl.read()
+        common.verbosePrint(
+            "* appended value: %s\n"
+            "* read value: %s\n"
+            % (appended, read) )
         self.assertEqual(appended, read, "Written and read values differ.")
 
 
     def test03_setitem(self):
         """Changing enumerated values using ``table.__setitem__()``."""
 
-        self._verboseHeader()
         tbl = self.h5file.createTable(
             '/', 'test', self._description(), title=self._getMethodName())
 
@@ -357,23 +309,24 @@ class EnumTableTestCase(common.TempFileMixin, common.PyTablesTestCase):
             (10, self.valueInEnum),
             (20, self.valueOutOfEnum)]
         tbl[:] = written
-        read = tbl.read(flavor='python')
-        if verbose:
-            print "written value:", written
-            print "read value:", read
+        tbl.flavor = 'python'
+        read = tbl.read()
+        common.verbosePrint(
+            "* written value: %s\n"
+            "* read value: %s\n"
+            % (written, read) )
         self.assertEqual(written, read, "Written and read values differ.")
 
 
     def test04_multidim(self):
         """Appending multi-dimensional enumerated data."""
 
-        self._verboseHeader()
         tbl = self.h5file.createTable(
             '/', 'test', self._description((2,)), title=self._getMethodName())
 
-        appended = (
+        appended = [
             (10, (self.valueInEnum, self.valueOutOfEnum)),
-            (20, (self.valueInEnum, self.valueOutOfEnum)))
+            (20, (self.valueInEnum, self.valueOutOfEnum))]
 
         row = tbl.row
         row['rid'] = appended[0][0]
@@ -382,7 +335,8 @@ class EnumTableTestCase(common.TempFileMixin, common.PyTablesTestCase):
 
         tbl.append(appended)
         tbl.flush()
-        read = tbl.read(flavor='python')
+        tbl.flavor = 'python'
+        read = tbl.read()
         for i in range(len(appended)):
             self.assertEqual(appended[i][0], read[i][0],
                              "Written and read values differ.")
@@ -395,7 +349,6 @@ class EnumTableTestCase(common.TempFileMixin, common.PyTablesTestCase):
     def test05_where(self):
         """Searching enumerated data."""
 
-        self._verboseHeader()
         tbl = self.h5file.createTable(
             '/', 'test', self._description(), title=self._getMethodName())
 
@@ -406,9 +359,9 @@ class EnumTableTestCase(common.TempFileMixin, common.PyTablesTestCase):
         tbl.append(appended)
         tbl.flush()
 
-        #searched = tuple(tbl.where(tbl.cols.rcolor == self.valueInEnum))
-        searched = [(row["rid"], row["rcolor"]) for row \
-                    in tbl.where(tbl.cols.rcolor == self.valueInEnum)]
+        searched = [
+            (row['rid'], row['rcolor'])
+            for row in tbl.where('rcolor == v', {'v': self.valueInEnum}) ]
         common.verbosePrint(
             "* ``valueInEnum``: %s\n"
             "* ``rcolor`` column: ``%s``\n"
@@ -427,20 +380,21 @@ class EnumEArrayTestCase(common.TempFileMixin, common.PyTablesTestCase):
     enum = tables.Enum({'red': 4, 'green': 2, 'blue': 1, 'black': 0})
     valueInEnum = enum.red
     valueOutOfEnum = 1234
-    enumType = 'UInt16'
+    enumType = 'uint16'
 
 
-    def _atom(self, shape=(0,)):
+    def _atom(self, shape=1):
         return tables.EnumAtom(
-            self.enum, dtype=self.enumType, shape=shape, flavor='python')
+            self.enum, 'red', base=self.enumType, shape=shape)
 
 
     def test00a_reopen(self):
         """Reopening a file with extendable arrays using enumerated data."""
 
-        self._verboseHeader()
         self.h5file.createEArray(
-            '/', 'test', self._atom(), title=self._getMethodName())
+            '/', 'test', self._atom(), shape=(0,),
+            title=self._getMethodName() )
+        self.h5file.root.test.flavor = 'python'
 
         self._reopen()
 
@@ -455,9 +409,10 @@ class EnumEArrayTestCase(common.TempFileMixin, common.PyTablesTestCase):
         multi-dimensional data.
         """
 
-        self._verboseHeader()
         self.h5file.createEArray(
-            '/', 'test', self._atom((0, 2)), title=self._getMethodName())
+            '/', 'test', self._atom(), shape=(0, 2),
+            title=self._getMethodName() )
+        self.h5file.root.test.flavor = 'python'
 
         self._reopen()
 
@@ -469,9 +424,10 @@ class EnumEArrayTestCase(common.TempFileMixin, common.PyTablesTestCase):
     def test01_append(self):
         """Appending scalar elements of enumerated values."""
 
-        self._verboseHeader()
         earr = self.h5file.createEArray(
-            '/', 'test', self._atom(), title=self._getMethodName())
+            '/', 'test', self._atom(), shape=(0,),
+            title=self._getMethodName() )
+        earr.flavor = 'python'
 
         appended = [self.valueInEnum, self.valueOutOfEnum]
 
@@ -484,9 +440,10 @@ class EnumEArrayTestCase(common.TempFileMixin, common.PyTablesTestCase):
     def test02_appendMD(self):
         """Appending multi-dimensional elements of enumerated values."""
 
-        self._verboseHeader()
         earr = self.h5file.createEArray(
-            '/', 'test', self._atom((0, 2)), title=self._getMethodName())
+            '/', 'test', self._atom(), shape=(0, 2),
+            title=self._getMethodName() )
+        earr.flavor = 'python'
 
         appended = [
             [self.valueInEnum, self.valueOutOfEnum],
@@ -501,9 +458,10 @@ class EnumEArrayTestCase(common.TempFileMixin, common.PyTablesTestCase):
     def test03_setitem(self):
         """Changing enumerated values using ``earray.__setitem__()``."""
 
-        self._verboseHeader()
         earr = self.h5file.createEArray(
-            '/', 'test', self._atom(), title=self._getMethodName())
+            '/', 'test', self._atom(), shape=(0,),
+            title=self._getMethodName() )
+        earr.flavor = 'python'
 
         appended = (self.valueInEnum, self.valueInEnum)
         earr.append(appended)
@@ -522,20 +480,21 @@ class EnumVLArrayTestCase(common.TempFileMixin, common.PyTablesTestCase):
     enum = tables.Enum({'red': 4, 'green': 2, 'blue': 1, 'black': 0})
     valueInEnum = enum.red
     valueOutOfEnum = 1234
-    enumType = 'UInt16'
+    enumType = 'uint16'
 
 
     def _atom(self, shape=1):
         return tables.EnumAtom(
-            self.enum, dtype=self.enumType, shape=shape, flavor='python')
+            self.enum, 'red', base=self.enumType, shape=shape)
 
 
     def test00a_reopen(self):
         """Reopening a file with variable-length arrays using enumerated data."""
 
-        self._verboseHeader()
         self.h5file.createVLArray(
-            '/', 'test', self._atom(), title=self._getMethodName())
+            '/', 'test', self._atom(),
+            title=self._getMethodName() )
+        self.h5file.root.test.flavor = 'python'
 
         self._reopen()
 
@@ -550,9 +509,10 @@ class EnumVLArrayTestCase(common.TempFileMixin, common.PyTablesTestCase):
         multi-dimensional data.
         """
 
-        self._verboseHeader()
         self.h5file.createVLArray(
-            '/', 'test', self._atom((2,)), title=self._getMethodName())
+            '/', 'test', self._atom((2,)),
+            title=self._getMethodName() )
+        self.h5file.root.test.flavor = 'python'
 
         self._reopen()
 
@@ -564,9 +524,10 @@ class EnumVLArrayTestCase(common.TempFileMixin, common.PyTablesTestCase):
     def test01_append(self):
         """Appending scalar elements of enumerated values."""
 
-        self._verboseHeader()
         vlarr = self.h5file.createVLArray(
-            '/', 'test', self._atom(), title=self._getMethodName())
+            '/', 'test', self._atom(),
+            title=self._getMethodName() )
+        vlarr.flavor = 'python'
 
         appended = [
             [self.valueInEnum,],
@@ -576,18 +537,20 @@ class EnumVLArrayTestCase(common.TempFileMixin, common.PyTablesTestCase):
         vlarr.append(appended[1])
         vlarr.flush()
         read = vlarr.read()
-        if verbose:
-            print "appended value:", appended
-            print "read value:", read
+        common.verbosePrint(
+            "* appended value: %s\n"
+            "* read value: %s\n"
+            % (appended, read) )
         self.assertEqual(appended, read, "Written and read values differ.")
 
 
     def test02_appendMD(self):
         """Appending multi-dimensional elements of enumerated values."""
 
-        self._verboseHeader()
         vlarr = self.h5file.createVLArray(
-            '/', 'test', self._atom((2,)), title=self._getMethodName())
+            '/', 'test', self._atom((2,)),
+            title=self._getMethodName() )
+        vlarr.flavor = 'python'
 
         appended = [
             [[self.valueInEnum, self.valueInEnum],],
@@ -598,18 +561,20 @@ class EnumVLArrayTestCase(common.TempFileMixin, common.PyTablesTestCase):
         vlarr.append(appended[1])
         vlarr.flush()
         read = vlarr.read()
-        if verbose:
-            print "appended value:", appended
-            print "read value:", read
+        common.verbosePrint(
+            "* appended value: %s\n"
+            "* read value: %s\n"
+            % (appended, read) )
         self.assertEqual(appended, read, "Written and read values differ.")
 
 
     def test03_setitem(self):
         """Changing enumerated values using ``vlarray.__setitem__()``."""
 
-        self._verboseHeader()
         vlarr = self.h5file.createVLArray(
-            '/', 'test', self._atom(), title=self._getMethodName())
+            '/', 'test', self._atom(),
+            title=self._getMethodName() )
+        vlarr.flavor = 'python'
 
         appended = (self.valueInEnum, self.valueInEnum)
         vlarr.append(appended)
@@ -617,9 +582,10 @@ class EnumVLArrayTestCase(common.TempFileMixin, common.PyTablesTestCase):
         written = [self.valueInEnum, self.valueOutOfEnum]
         vlarr[0] = written
         read = vlarr.read()
-        if verbose:
-            print "written value:", written
-            print "read value:", read[0]
+        common.verbosePrint(
+            "* written value: %s\n"
+            "* read value: %s\n"
+            % (written, read) )
         self.assertEqual(written, read[0], "Written and read values differ.")
 
 
@@ -629,13 +595,13 @@ def suite():
 
     # These two are for including Enum's doctests here.
     import doctest
-    import tables.enum
+    from tables.misc import enum
     theSuite = unittest.TestSuite()
     niter = 1
 
     #theSuite.addTest(unittest.makeSuite(EnumTableTestCase))
     for i in range(niter):
-        theSuite.addTest(doctest.DocTestSuite(tables.enum))
+        theSuite.addTest(doctest.DocTestSuite(enum))
         theSuite.addTest(unittest.makeSuite(CreateColTestCase))
         theSuite.addTest(unittest.makeSuite(CreateAtomTestCase))
         theSuite.addTest(unittest.makeSuite(EnumTableTestCase))
