@@ -2,20 +2,15 @@ import sys
 import unittest
 import os
 import tempfile
+
 from tables import *
+from tables.tests import common
 
-from common import verbose, cleanup
 # To delete the internal attributes automagically
-unittest.TestCase.tearDown = cleanup
-
-# Check if we are using python 2.2
-if sys.version_info[0] == 2 and sys.version_info[1] == 2:
-    python22 = 1
-else:
-    python22 = 0
+unittest.TestCase.tearDown = common.cleanup
 
 def WriteRead(filename, testTuple):
-    if verbose:
+    if common.verbose:
         print '\n', '-=' * 30
         print "Running test for object %s" % \
                   (type(testTuple))
@@ -39,7 +34,7 @@ def WriteRead(filename, testTuple):
     try:
         b = root.somearray.read()
         # Compare them. They should be equal.
-        if not a == b and verbose:
+        if not a == b and common.verbose:
             print "Write and read lists/tuples differ!"
             print "Object written:", a
             print "Object read:", b
@@ -124,7 +119,7 @@ class ExceptionTestCase(unittest.TestCase):
     def test00_char(self):
         "Non suppported lists objects (character objects)"
 
-        if verbose:
+        if common.verbose:
             print '\n', '-=' * 30
             print "Running test for %s" % \
                   (self.title)
@@ -135,13 +130,13 @@ class ExceptionTestCase(unittest.TestCase):
                 WriteRead(fname, a)
             finally:
                 os.remove(fname)
-        except TypeError:
-            if verbose:
+        except ValueError:
+            if common.verbose:
                 (type, value, traceback) = sys.exc_info()
                 print "\nGreat!, the next error was catched!"
                 print type, ":", value
         else:
-            self.fail("expected an TypeError")
+            self.fail("expected a ValueError")
 
 
         return
@@ -157,9 +152,9 @@ class ExceptionTestCase(unittest.TestCase):
             finally:
                 os.remove(fname)
         except ValueError:
-            if verbose:
+            if common.verbose:
                 (type, value, traceback) = sys.exc_info()
-                print "\nGreat!, the next ValueError was catched!"
+                print "\nGreat!, the next was catched!"
                 print value
         else:
             self.fail("expected an ValueError")
@@ -185,7 +180,7 @@ class GetItemTestCase(unittest.TestCase):
         arr=fileh.createArray(fileh.root, 'somearray', a, "Some array")
 
         # Get and compare an element
-        if verbose:
+        if common.verbose:
             print "Original first element:", a[0]
             print "Read first element:", arr[0]
         assert a[0] == arr[0]
@@ -206,7 +201,7 @@ class GetItemTestCase(unittest.TestCase):
         arr=fileh.createArray(fileh.root, 'somearray', a, "Some array")
 
         # Get and compare an element
-        if verbose:
+        if common.verbose:
             print "Original first element:", a[0]
             print "Read first element:", arr[0]
         assert a[0] == arr[0]
@@ -227,7 +222,7 @@ class GetItemTestCase(unittest.TestCase):
         arr=fileh.createArray(fileh.root, 'somearray', a, "Some array")
 
         # Get and compare an element
-        if verbose:
+        if common.verbose:
             print "Original elements:", a[1:4]
             print "Read elements:", arr[1:4]
         assert a[1:4] == arr[1:4]
@@ -248,7 +243,7 @@ class GetItemTestCase(unittest.TestCase):
         arr=fileh.createArray(fileh.root, 'somearray', a, "Some array")
 
         # Get and compare an element
-        if verbose:
+        if common.verbose:
             print "Original elements:", a[1:4]
             print "Read elements:", arr[1:4]
         assert a[1:4] == arr[1:4]
@@ -261,7 +256,6 @@ class GetItemTestCase(unittest.TestCase):
 
     def test04_range(self):
         "Range element access, strided (character types)"
-        global python22
 
         file = tempfile.mktemp(".h5")
         fileh = openFile(file, mode = "w")
@@ -269,13 +263,11 @@ class GetItemTestCase(unittest.TestCase):
         a = self.charListME
         arr=fileh.createArray(fileh.root, 'somearray', a, "Some array")
 
-        # Extended slicing not supported in Python 2.2
-        if not python22:
-            # Get and compare an element
-            if verbose:
-                print "Original elements:", a[1:4:2]
-                print "Read elements:", arr[1:4:2]
-            assert a[1:4:2] == arr[1:4:2]
+        # Get and compare an element
+        if common.verbose:
+            print "Original elements:", a[1:4:2]
+            print "Read elements:", arr[1:4:2]
+        assert a[1:4:2] == arr[1:4:2]
 
         # Close the file
         fileh.close()
@@ -285,7 +277,6 @@ class GetItemTestCase(unittest.TestCase):
 
     def test05_range(self):
         "Range element access (numerical types)"
-        global python22
 
         file = tempfile.mktemp(".h5")
         fileh = openFile(file, mode = "w")
@@ -293,13 +284,11 @@ class GetItemTestCase(unittest.TestCase):
         a = self.numericalListME
         arr=fileh.createArray(fileh.root, 'somearray', a, "Some array")
 
-        # Extended slicing not supported in Python 2.2
-        if not python22:
-            # Get and compare an element
-            if verbose:
-                print "Original elements:", a[1:4:2]
-                print "Read elements:", arr[1:4:2]
-            assert a[1:4:2] == arr[1:4:2]
+        # Get and compare an element
+        if common.verbose:
+            print "Original elements:", a[1:4:2]
+            print "Read elements:", arr[1:4:2]
+        assert a[1:4:2] == arr[1:4:2]
 
         # Close the file
         fileh.close()
@@ -317,7 +306,7 @@ class GetItemTestCase(unittest.TestCase):
         arr=fileh.createArray(fileh.root, 'somearray', a, "Some array")
 
         # Get and compare an element
-        if verbose:
+        if common.verbose:
             print "Original last element:", a[-1]
             print "Read last element:", arr[-1]
         assert a[-1] == arr[-1]
@@ -338,7 +327,7 @@ class GetItemTestCase(unittest.TestCase):
         arr=fileh.createArray(fileh.root, 'somearray', a, "Some array")
 
         # Get and compare an element
-        if verbose:
+        if common.verbose:
             print "Original before last element:", a[-2]
             print "Read before last element:", arr[-2]
         assert a[-2] == arr[-2]
@@ -359,7 +348,7 @@ class GetItemTestCase(unittest.TestCase):
         arr=fileh.createArray(fileh.root, 'somearray', a, "Some array")
 
         # Get and compare an element
-        if verbose:
+        if common.verbose:
             print "Original last elements:", a[-4:-1]
             print "Read last elements:", arr[-4:-1]
         assert a[-4:-1] == arr[-4:-1]
@@ -380,7 +369,7 @@ class GetItemTestCase(unittest.TestCase):
         arr=fileh.createArray(fileh.root, 'somearray', a, "Some array")
 
         # Get and compare an element
-        if verbose:
+        if common.verbose:
             print "Original last elements:", a[-4:-1]
             print "Read last elements:", arr[-4:-1]
         assert a[-4:-1] == arr[-4:-1]
@@ -431,7 +420,7 @@ class GeneratorTestCase(unittest.TestCase):
         # Get and compare an element
         ga = [i for i in a]
         garr = [i for i in arr]
-        if verbose:
+        if common.verbose:
             print "Result of original iterator:", ga
             print "Result of read generator:", garr
         assert ga == garr
@@ -457,7 +446,7 @@ class GeneratorTestCase(unittest.TestCase):
         else:
             ga = [i for i in a]
         garr = [i for i in arr]
-        if verbose:
+        if common.verbose:
             print "Result of original iterator:", ga
             print "Result of read generator:", garr
         assert ga == garr
@@ -480,7 +469,7 @@ class GeneratorTestCase(unittest.TestCase):
         # Get and compare an element
         ga = [i for i in a]
         garr = [i for i in arr]
-        if verbose:
+        if common.verbose:
             print "Result of original iterator:", ga
             print "Result of read generator:", garr
         assert ga == garr
@@ -506,7 +495,7 @@ class GeneratorTestCase(unittest.TestCase):
         else:
             ga = [i for i in a]
         garr = [i for i in arr]
-        if verbose:
+        if common.verbose:
             print "Result of original iterator:", ga
             print "Result of read generator:", garr
         assert ga == garr
